@@ -20,7 +20,7 @@ pub struct Contents {
 #[serde(rename_all = "camelCase")]
 pub struct TwoColumnWatchNextResults {
     pub results: Results,
-    pub secondary_results: SecondaryResults,
+    pub secondary_results: Option<SecondaryResults>,
 }
 
 #[derive(Clone, Deserialize)]
@@ -73,7 +73,7 @@ pub enum Content {
 #[derive(Clone, Deserialize)]
 #[serde(rename_all = "camelCase")]
 pub struct VideoPrimaryInfoRenderer {
-    pub sentiment_bar: Option<SentimentBar>,
+    pub video_actions: VideoActions,
     #[serde(default)]
     pub super_title_link: SuperTitleLink,
     pub date_text: SimpleText,
@@ -81,23 +81,26 @@ pub struct VideoPrimaryInfoRenderer {
 
 impl VideoPrimaryInfoRenderer {
     pub fn ratings(&self) -> Option<(u64, u64)> {
-        let fixed_tooltip = self
-            .sentiment_bar
+        // `like this video along with 4,457 other people` or `I like this`
+        let label = &self
+            .video_actions
+            .menu_renderer
+            .like_button()?
+            .accessibility
             .as_ref()?
-            .sentiment_bar_renderer
-            .tooltip
-            .replace(',', "");
+            .label;
 
-        let (likes, dislikes) = fixed_tooltip
-            .split_once(" / ")
-            .expect("sentimentBar tooltip did not have a '/'");
+        let (_, likes) = label.split_once("like this video along with ")?;
+        let (likes, _) = likes.split_once(" other people")?;
+
+        let likes = likes.replace(',', "");
 
         let likes = likes
             .parse()
             .expect("Likes we not parsable as a unsigned integer");
-        let dislikes = dislikes
-            .parse()
-            .expect("Dislikes we not parsable as a unsigned integer");
+
+        // TODO: remove `ratings()` and replace it with `likes()` with v0.11.0
+        let dislikes = 0;
 
         Some((likes, dislikes))
     }
@@ -106,17 +109,46 @@ impl VideoPrimaryInfoRenderer {
         self.super_title_link.runs.iter().map(|x| x.text.as_str())
     }
 }
-
-#[derive(Clone, Deserialize)]
+#[derive(Clone, Deserialize, Default)]
 #[serde(rename_all = "camelCase")]
-pub struct SentimentBar {
-    pub sentiment_bar_renderer: SentimentBarRenderer,
+pub struct VideoActions {
+    pub menu_renderer: MenuRenderer,
+}
+
+#[derive(Clone, Deserialize, Default)]
+#[serde(rename_all = "camelCase")]
+pub struct MenuRenderer {
+    pub top_level_buttons: Vec<TopLevelButton>,
+}
+
+impl MenuRenderer {
+    fn like_button(&self) -> Option<&ToggleButtonRenderer> {
+        self.top_level_buttons.iter().find_map(|x| match x {
+            &TopLevelButton::ToggleButtonRenderer(ref button) => Some(button),
+            &TopLevelButton::ButtonRenderer {} => None,
+            &TopLevelButton::DownloadButtonRenderer {} => None,
+        })
+    }
 }
 
 #[derive(Clone, Deserialize)]
 #[serde(rename_all = "camelCase")]
-pub struct SentimentBarRenderer {
-    pub tooltip: String,
+pub enum TopLevelButton {
+    ToggleButtonRenderer(ToggleButtonRenderer),
+    DownloadButtonRenderer {},
+    ButtonRenderer {},
+}
+
+#[derive(Clone, Deserialize, Default)]
+#[serde(rename_all = "camelCase")]
+pub struct ToggleButtonRenderer {
+    pub accessibility: Option<AccessibilityData>,
+}
+
+#[derive(Clone, Deserialize, Default)]
+#[serde(rename_all = "camelCase")]
+pub struct AccessibilityData {
+    pub label: String,
 }
 
 #[derive(Clone, Deserialize, Default)]
@@ -232,7 +264,7 @@ pub struct CompactPlaylistRenderer {
     pub thumbnail: Thumbnails,
     pub title: SimpleText,
     // channel name
-    pub short_byline_text: ChannelNameRuns,
+    pub short_byline_text: super::Runs<OptionalChannelNameRun>,
     // length
     pub video_count_short_text: SimpleText,
 
@@ -257,19 +289,29 @@ pub struct CompactMovieRenderer {
     pub length_text: SimpleText,
 }
 
+#[derive(Deserialize, Clone)]
+#[serde(rename_all = "camelCase")]
+pub struct OptionalChannelNameRun {
+    pub text: String,
+    pub navigation_endpoint: Option<super::NavigationEndpoint>,
+}
+
 #[derive(Deserialize)]
 #[serde(rename_all = "camelCase")]
 pub struct Continuation {
-    pub on_response_received_endpoints: (OnResponseReceivedAction,),
+    pub on_response_received_endpoints: Option<(OnResponseReceivedAction,)>,
 }
 
 impl Continuation {
     pub fn into_videos(self) -> impl Iterator<Item = RelatedItem> {
-        self.on_response_received_endpoints
-            .0
-            .append_continuation_items_action
-            .continuation_items
-            .into_iter()
+        if let Some(end) = self.on_response_received_endpoints {
+            end.0
+                .append_continuation_items_action
+                .continuation_items
+                .into_iter()
+        } else {
+            vec![].into_iter()
+        }
     }
 }
 
